@@ -71,8 +71,8 @@ construct_Q_n <- function(type, dat_v, vals, return_model=F) {
 
     # Prevents CRAN Note
     if (F) {
-      x <- earth::earth
-      x <- glmnet::glmnet
+      # x <- earth::earth
+      # x <- glmnet::glmnet
       x <- e1071::svm
     }
 
@@ -937,8 +937,9 @@ construct_gamma_n <- function(dat_v, type="Super Learner", omega_n,
 
     # Fit SuperLearner regression
     do.call("library", list("SuperLearner"))
-    SL.library <- c("SL.mean", "SL.gam", "SL.ranger", "SL.earth", "SL.loess",
-                    "SL.nnet", "SL.ksvm", "SL.rpartPrune", "SL.svm")
+    # SL.library <- c("SL.mean", "SL.gam", "SL.ranger", "SL.earth", "SL.loess",
+    #                 "SL.nnet", "SL.ksvm", "SL.rpartPrune", "SL.svm")
+    SL.library <- c("SL.mean", "SL.gam", "SL.ranger", "SL.svm") # Changed on 2024-02-13
 
     model_sl <- SuperLearner::SuperLearner(
       Y = dat_v2$po,
@@ -973,11 +974,20 @@ construct_gamma_n <- function(dat_v, type="Super Learner", omega_n,
 construct_g_zn <- function(dat_v, type="Super Learner", f_sIx_n,
                            f_sIx_z1_n) {
 
+  # Prevents CRAN Note
+  if (F) {
+    x <- ranger::ranger
+    x <- gam::gam
+  }
+
   # Set library
   if (type=="Super Learner") {
     do.call("library", list("SuperLearner"))
-    SL.library <- c("SL.mean", "SL.gam", "SL.ranger", "SL.earth", "SL.nnet",
-                    "SL.glmnet")
+    # SL.library <- c("SL.mean", "SL.gam", "SL.ranger", "SL.earth", "SL.nnet",
+    #                 "SL.glmnet")
+    # SL.library <- c("SL.mean", "SL.gam", "SL.ranger", "SL.nnet",
+    #                 "SL.glmnet")
+    SL.library <- c("SL.mean", "SL.gam", "SL.ranger", "SL.svm") # Changed 2024-02-13
   } else if (type=="logistic") {
     SL.library <- c("SL.glm")
   }
